(eid x)Coerce to entity id, keyword, lookup ref, or nil if invalid.
Coerce to entity id, keyword, lookup ref, or nil if invalid.
(entity? entity)Returns true if entity is an EntityMap
Returns true if entity is an EntityMap
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |